/**
 * --------------------------------------------------------------------------
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010-2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.classloader.view {

import com.adobe.cairngorm.control.CairngormEventDispatcher;

import flash.events.MouseEvent;

import mx.containers.VBox;
import mx.controls.CheckBox;
import mx.controls.List;
import mx.controls.TextInput;
import mx.events.FlexEvent;
import mx.events.ItemClickEvent;

import org.ow2.jonas.admin.classloader.event.GetClassLoaderApplicationReportEvent;
import org.ow2.jonas.admin.classloader.event.GetExportedPackagesEvent;
import org.ow2.jonas.admin.classloader.event.GetObjectNameGetResourcesEvent;
import org.ow2.jonas.admin.classloader.event.GetObjectNameLoadClassEvent;
import org.ow2.jonas.admin.classloader.event.GetStandaloneApplicationsEvent;
import org.ow2.jonas.admin.classloader.event.GetSystemResourcesEvent;
import org.ow2.jonas.admin.classloader.model.ClassLoaderModelLocator;
import org.ow2.kerneos.common.event.KerneosNotificationEvent;


/**
 * Defines the parent class of the MXML component.
 * @author Florent Benoit
 */
public class ClassLoaderClass extends VBox {

    /**
     * Model used for this view.
     */
    [Bindable]
    public var model:ClassLoaderModelLocator = ClassLoader.getInstance().getModel();


    /**
     * List of all applications.
     */
    [Bindable]
    public var listApplications:List;

    /**
     * CheckBoxes
     */
    [Bindable]
    public var checkBoxEAR:CheckBox;
    public var checkBoxEJBJAR:CheckBox;
    public var checkBoxWAR:CheckBox;

    /**
     * Filter for searching applications.
     */
    public var applicationFilter:TextInput;

    /**
     * Text Input for the search entry.
     */
    [Bindable]
    public var searchEntry:TextInput;

    /**
     * Text Input for loading a class for a given objectname.
     */
    [Bindable]
    public var loadClassObjectNameTextInput:TextInput;

    /**
     * Text Input for getting resources for a given objectname.
     */
    [Bindable]
    public var getResourcesObjectNameTextInput:TextInput;


    [Bindable]
    public var startedModule:Boolean = false;

    protected const dispatcher:CairngormEventDispatcher = ClassLoader.getInstance().getDispatcher();


    /**
     * Default constructor.
     */
    public function ClassLoaderClass():void {
        addEventListener(FlexEvent.CREATION_COMPLETE, creationCompleteHandler);
    }

    /**
     * Initiates the module.
     */

    public function initView():void {
        debug("Class Loader Module Initialized");
   }

    public function destroy():void {
        debug("Class Loader Module Removed");
   }


    /**
     * Handler called when object is created.
     */
    private function creationCompleteHandler(event:FlexEvent):void {

    }


    public function handleSearch(event:ItemClickEvent):void {
        if ("Class" == event.currentTarget.selectedValue) {
            model.searchMode = model.CLASS_SEARCH_MODE;
        } else if ("Package" == event.currentTarget.selectedValue) {
            model.searchMode = model.PACKAGE_SEARCH_MODE;
        } else if ("Resource" == event.currentTarget.selectedValue) {
            model.searchMode = model.RESOURCE_SEARCH_MODE;
        }
    }

    protected function refreshStandaloneApplications(event:MouseEvent):void {
        var getStandaloneApplicationsEvent:GetStandaloneApplicationsEvent = new GetStandaloneApplicationsEvent(GetStandaloneApplicationsEvent.EVENT_GET_STANDALONE_APPLICATIONS, applicationFilter.text, checkBoxEAR.selected, checkBoxEJBJAR.selected, checkBoxWAR.selected);
        dispatcher.dispatchEvent(getStandaloneApplicationsEvent);
    }

    // Selecting an application
    protected function selectingApplications(event:MouseEvent):void {

        model.xmlClassLoaderInfoReport = null;
        model.xmlSelectedClassLoader = null;
        model.xmlClassLoaderObjectNameLoadClassResult = null;
        model.selectedClassLoaderObjectName = null;

        var objectName:String = listApplications.selectedItem.objectName;
        if (objectName != null) {
            var getClassLoaderApplicationReportEvent:GetClassLoaderApplicationReportEvent = new GetClassLoaderApplicationReportEvent(GetClassLoaderApplicationReportEvent.EVENT_GET_CLASSLOADER_APPLICATION_REPORT, objectName);
            dispatcher.dispatchEvent(getClassLoaderApplicationReportEvent);
        }

    }

    // Search the given resource
    public function searchButton_clickHandler(event:MouseEvent):void {

        // reset model
        model.xmlPackages = null;
        model.systemResources = null;
        model.nothingHasBeenFoundDuringSearch = false;

        // Searching the entry
        if (model.searchMode == model.CLASS_SEARCH_MODE || model.searchMode == model.PACKAGE_SEARCH_MODE) {

            // Send an event to get data
            var getExportedPackagesEvent:GetExportedPackagesEvent = new GetExportedPackagesEvent(GetExportedPackagesEvent.EVENT_GET_EXPORTED_PACKAGES, searchEntry.text, model.searchMode == model.CLASS_SEARCH_MODE);
            dispatcher.dispatchEvent(getExportedPackagesEvent);
        } else {
            // Send an event to get data
            var getSystemResourcesEvent:GetSystemResourcesEvent = new GetSystemResourcesEvent(GetSystemResourcesEvent.EVENT_GET_SYSTEM_RESOURCES, searchEntry.text);
            dispatcher.dispatchEvent(getSystemResourcesEvent);
        }


    }

    protected function closeGraph(e:MouseEvent):void {
        model.showingGraph = false;
        model.xmlSelectedClassLoader = null;
        model.xmlClassLoaderInfoReport = null;
        model.xmlClassLoaderObjectNameLoadClassResult = null;
        model.selectedClassLoaderObjectName = null;
        model.arrayClassLoaderObjectNameGetResourcesResult = null;
    }


    public function isWar(xml:XML):Boolean {
        if (xml == null) {
            return false;
        }
        var data:XMLList = xml.attribute('delegation-model');
        return (data != null && data.length() > 0);

    }


    public function loadClassObjectNameClick(e:MouseEvent):void {

        if (model.xmlSelectedClassLoader != null) {
            var objectName:String = model.selectedClassLoaderObjectName;
            var className:String = loadClassObjectNameTextInput.text;
            // Send an event to get data
            var getObjectNameLoadClassEvent:GetObjectNameLoadClassEvent = new GetObjectNameLoadClassEvent(GetObjectNameLoadClassEvent.EVENT_GET_OBJECTNAME_LOADCLASS, objectName, className);
            dispatcher.dispatchEvent(getObjectNameLoadClassEvent);

        }
    }

    public function getResourcesObjectNameClick(e:MouseEvent):void {

        if (model.xmlSelectedClassLoader != null) {
            var objectName:String = model.selectedClassLoaderObjectName;
            var resourceName:String = getResourcesObjectNameTextInput.text;
            // Send an event to get data
            var getObjectNameGetResourcesEvent:GetObjectNameGetResourcesEvent = new GetObjectNameGetResourcesEvent(GetObjectNameGetResourcesEvent.EVENT_GET_OBJECTNAME_GET_RESOURCES, objectName, resourceName);
            dispatcher.dispatchEvent(getObjectNameGetResourcesEvent);

        }
    }
                 
    public function debug(message:String):void {
        dispatchEvent(new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION,
                message, KerneosNotificationEvent.DEBUG));
    }


}
}
